/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */

package org.bsf.listOfValues;

import org.bsf.listOfValues.exceptions.NoSuchLovValueException;
import org.bsf.listOfValues.lovValue.LovValue;

import java.rmi.RemoteException;
import java.util.HashMap;
import java.util.List;

/**
 * Defines the way that Objects holding the access to a List Of Values (LOV)
 * should be accessed. Note that those LOV accessors (or providers) could be
 * stateless Enterprise Java Beans as well as usual Java classes (generating
 * the LOV on the fly for example).
 *
 * @see org.bsf.listOfValues.lovValue.LovValue
 */
public interface LovBusinessInterface {
    /**
     * Returns the LovValue corresponding to the given OID in the List Of Values
     * held in the implementing Object.
     *
     * @param p_lovValueOID The OID, in the List Of Values held in the implementing
     * Object, of the LovValue desired.
     * @return the LovValue corresponding to the given oid.
     */
    public LovValue getLovValue( Long p_lovValueOID ) throws RemoteException, NoSuchLovValueException;

    /**
     * Gets the LOV mapped by OID.
     *
     * @return a HashMap of (key=OID, object=LovValue).
     */
    public HashMap getLovValuesPerOID() throws RemoteException;

    /**
     * Gets the LovValues in the order of their retrieval (for example if we
     * retrieve them by using a EJB BMP and the LOV_REQUESTS table we will get
     * them in the order of the result of the executed SQL).
     *
     * @return A List containing the LovValues.
     */
    public List getListOfValues() throws RemoteException;
}
