/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */

package org.bsf.listOfValues.lovValue;

import java.io.Serializable;

/**
 * Any Object that implements this interface can be handled as a LovValue. A
 * LovValue contains Objects associated to field names (ie. properties).<p>
 *
 * Note that we call ListOfValues a List of LovValue (where those LovValue can
 * be any Object implementing this interface).<p>
 *
 * A LovValue with three fields (Long, String, String) like (OID, SHORT_NAME, LONG_NAME)
 * would look like:
 *  (0,"None","Not defined") or (1,"FR","France") or (2,"UK","United Kingdom")
 * whereas a ListOfValues for the COUNTRIES (in our example) would be the List
 * of all those LovValue:
 *  {(0,"None","Not defined"),(1,"FR","France"),(2,"UK","United Kingdom")}
 *
 * @see org.bsf.listOfValues.LovBean
 * @see org.bsf.listOfValues.LovServiceBean
 */
public interface LovValue extends Serializable {
    /**
     * This method is deprecated since the 2.1 release. The PK of a LovValue is
     * to be defined like any other field (but in first position, cf. LovBean)
     * and can be of any type. Should still work with LovValues whose first field
     * are a Long to ease the transition to the new way of handling the LovValue.
     * Still, if defined in database, the LOV will have to be modified to include
     * the definition of the first field. 
     *
     * @return the OID of the LovValue. For a given ListOfValue (a List of
     * LovValues) a test on the OID should be enough to consider the LovValue
     * as equal).
     *
     * @deprecated
     */
    public Long getOid();

    /**
     * @return the pk of the LovValue. For a given ListOfValue (a List of
     * LovValues) a test on the pk should be enough to consider the LovValue
     * as equal).  The first defined field is considered to be the PK.
     */
    public Object getPK();

    /**
     * This method enable the access to the values stored in this LovValue for
     * the given field name.
     *
     * @param p_fieldName The field whose value is disired.
     * @return The Object for the given field name in the LovValue, null if no
     * matching field is found. The matching should be case insensitive.
     */
    public Object getFieldValue( String p_fieldName );
}